/**********************************************************
 
SaveForStocks.js	version 1.0

DESCRIPTION

This script saves the current Ai document as EPS and two JPGs of 
sizes required on the most popular microstocks istockphoto and 
shutterstock. The new files appear in the same folder.

Tested with Adobe Illustrator CS2 and CS3 on both Windows and 
Mac os X platforms.

TERMS OF USE

This script is distributed for free under GNU General Public
License.

**********************************************************

Copyright (c) 2008 Oleksandr Mikhnenko  http://mikhnenko.com
Written especially for the needs of Oksancia (Oksancia.com)

**********************************************************/

// Main Code [Execution of script begins here]

// uncomment to suppress Illustrator warning dialogs
// app.userInteractionLevel = UserInteractionLevel.DONTDISPLAYALERTS;

var Doc;			// we work with active document only
var fileType,  targetFile, jpgExportOpts, epsSaveOpts;
var Name;			// short filename with extention
var name1; 			// short filename without extention
var pathName;			// full filename with path
var destFolder;			// destination folder == current folder
var width, height;		// size of the image on the workspace
var statusMsg="\n";		// is shown at the end.


if (app.documents.length==0)
{
	alert("There are no documents opened. Nothing has been done.");
}else{

	Doc=activeDocument;
	
	Doc.save();
	Name=Doc.name;
	
	
	// get size of the image in pixels
	width=Doc.visibleBounds[2]-Doc.visibleBounds[0];
	height=Doc.visibleBounds[1]-Doc.visibleBounds[3];
	
	
	// check if the filename has extension 
	if (Name.indexOf('.') < 0) {
		name1 = Name;
	} else {
		var token = Name.lastIndexOf('.');
		name1 = Name.substring(0, token);
	}
	
	pathName=Doc.fullName+" "; // convert pathName to string. Otherwise lastIndexOf does not work
	token = pathName.lastIndexOf('/');
	destFolder = pathName.substring(0, token);
	
	
	///////////////////////////////////////////////////////
	// 
	//	Export JPGs
	//
	///////////////////////////////////////////////////////
	
	
	fileType = ExportType.JPEG;
	// Call function getJPGOptions get the ExportOptionsJPEG for the files
	if (jpgExportOpts = getJPGOptions(500, width, height ))
	{
	
		// Export as a jpg
	
		targetFile = new File(destFolder + '/' + name1);
		Doc.exportFile( targetFile, fileType, jpgExportOpts );
		statusMsg+="500 px JPG\t...\tOK\n"
	}else{
		statusMsg+="500 px JPG\t...\tFailed\n"
	}
	
	// Call function getJPGOptions get the ExportOptionsJPEG for the files
	if (jpgExportOpts = getJPGOptions(2800, width, height ))
	{
	
		// Export as a big jpg
	
		targetFile = new File(destFolder + '/' + name1 + '_big');
		Doc.exportFile( targetFile, fileType, jpgExportOpts );
		statusMsg+="2800 px JPG\t...\tOK\n"
	}else{
		statusMsg+="2800 px JPG\t...\tFailed\n"
	}
	
	///////////////////////////////////////////////////////
	// 
	//	Save as EPS
	//
	///////////////////////////////////////////////////////
	
	// Call function getESPOptions get the EPSSaveOptions for the files
	epsSaveOpts = getEPSOptions();
	targetFile = new File(destFolder + '/' + name1 + ".eps");
	Doc.saveAs(targetFile, epsSaveOpts);
	statusMsg+="EPS\t\t\t...\tOK\n"
	
	
	alert( 'The following files were saved to ' + destFolder +'\n' + statusMsg);
	
	var answer = confirm("Now EPS file is open.\nWould you like to close it and reopen the .ai file?");
	if (answer){
		Doc.close();
		targetFile = new File(destFolder + '/' + name1 + ".ai");
		app.open(targetFile);
	}
	
} 


/*********************************************************

getEPSOptions: Function to set the EPS saving options of the 
files using the EPSSaveOptions object.

**********************************************************/

function getEPSOptions()
{
	// Create the EPSSaveOptions object to set the PDF options
	var epsSaveOpts = new EPSSaveOptions();
	
	// Setting EPSSaveOptions properties. Please see the JavaScript Reference
	// for a description of these properties.
	epsSaveOpts.compatibility= Compatibility.ILLUSTRATOR8;
	epsSaveOpts.includeDocumentThumbnails = true;
	epsSaveOpts.postScript = EPSPostScriptLevelEnum.LEVEL2;
	epsSaveOpts.preview = EPSPreview.COLORTIFF; //default
	
	return epsSaveOpts;
}

/*********************************************************

getJPGOptions: Function to set the PDF saving options of the 
files using the EPSSaveOptions object.

**********************************************************/

function getJPGOptions(maxSize,width,height)
{
	var scaling;
	// Create the ExportOptionsJPEG object to set the JPG options
	var jpgExportOpts = new ExportOptionsJPEG();
	
	// Setting ExportOptionsJPEG properties. Please see the JavaScript Reference
	// for a description of these properties.
	jpgExportOpts.antiAliasing = true;
	jpgExportOpts.optimization = true;
	jpgExportOpts.qualitySetting = 100;

	if (width>height)
	{
		scaling=maxSize/width * 100;
	}else{
		scaling=maxSize/height *100;
	}

	if (scaling>776.19)
	{
		var needed=Math.round(scaling/776.19*10)/10;
		alert ("Warning!\n\nThe image is too small and due to the Illustrator limitations could not be resized to " + maxSize + "px.\n"+ "Please scale the image by at least " + needed + " times.");
		return 0;		
	}


	jpgExportOpts.horizontalScale = scaling;
	jpgExportOpts.verticalScale = scaling;


	return jpgExportOpts;
}
